==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/GetSqlPoolWorkloadClassifierPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.GetSqlPoolWorkloadClassifierPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sqlPoolName SQL pool name
 * @property workloadClassifierName The name of the workload classifier.
 * @property workloadGroupName The name of the workload group.
 * @property workspaceName The name of the workspace.
 */
public data class GetSqlPoolWorkloadClassifierPlainArgs(
    public val resourceGroupName: String,
    public val sqlPoolName: String,
    public val workloadClassifierName: String,
    public val workloadGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.GetSqlPoolWorkloadClassifierPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.GetSqlPoolWorkloadClassifierPlainArgs =
        com.pulumi.azurenative.synapse.inputs.GetSqlPoolWorkloadClassifierPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .sqlPoolName(sqlPoolName.let({ args0 -> args0 }))
            .workloadClassifierName(workloadClassifierName.let({ args0 -> args0 }))
            .workloadGroupName(workloadGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlPoolWorkloadClassifierPlainArgs].
 */
@PulumiTagMarker
public class GetSqlPoolWorkloadClassifierPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var sqlPoolName: String? = null

    private var workloadClassifierName: String? = null

    private var workloadGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("edgewyumamtsnumy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value SQL pool name
     */
    @JvmName("sugsosagdibamakl")
    public suspend fun sqlPoolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sqlPoolName = mapped
    }

    /**
     * @param value The name of the workload classifier.
     */
    @JvmName("yiecavuyyjbvynph")
    public suspend fun workloadClassifierName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workloadClassifierName = mapped
    }

    /**
     * @param value The name of the workload group.
     */
    @JvmName("ikxywmjyqmecjneo")
    public suspend fun workloadGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workloadGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("scmwhmqsghkexuvn")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetSqlPoolWorkloadClassifierPlainArgs =
        GetSqlPoolWorkloadClassifierPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            sqlPoolName = sqlPoolName ?: throw PulumiNullFieldException("sqlPoolName"),
            workloadClassifierName = workloadClassifierName ?: throw
                PulumiNullFieldException("workloadClassifierName"),
            workloadGroupName = workloadGroupName ?: throw PulumiNullFieldException("workloadGroupName"),
            workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/GetSqlPoolWorkloadClassifierPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.GetSqlPoolWorkloadClassifierPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sqlPoolName SQL pool name
 * @property workloadClassifierName The name of the workload classifier.
 * @property workloadGroupName The name of the workload group.
 * @property workspaceName The name of the workspace.
 */
public data class GetSqlPoolWorkloadClassifierPlainArgs(
    public val resourceGroupName: String,
    public val sqlPoolName: String,
    public val workloadClassifierName: String,
    public val workloadGroupName: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.GetSqlPoolWorkloadClassifierPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.GetSqlPoolWorkloadClassifierPlainArgs =
        com.pulumi.azurenative.synapse.inputs.GetSqlPoolWorkloadClassifierPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .sqlPoolName(sqlPoolName.let({ args0 -> args0 }))
            .workloadClassifierName(workloadClassifierName.let({ args0 -> args0 }))
            .workloadGroupName(workloadGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlPoolWorkloadClassifierPlainArgs].
 */
@PulumiTagMarker
public class GetSqlPoolWorkloadClassifierPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var sqlPoolName: String? = null

    private var workloadClassifierName: String? = null

    private var workloadGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("amybsfpmnyeaphtx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value SQL pool name
     */
    @JvmName("jdwmminhuljukyem")
    public suspend fun sqlPoolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sqlPoolName = mapped
    }

    /**
     * @param value The name of the workload classifier.
     */
    @JvmName("jehvppvxcltayefu")
    public suspend fun workloadClassifierName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workloadClassifierName = mapped
    }

    /**
     * @param value The name of the workload group.
     */
    @JvmName("jiaasvhvboldhrls")
    public suspend fun workloadGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workloadGroupName = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("xqulvfqkhncqqcqe")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetSqlPoolWorkloadClassifierPlainArgs =
        GetSqlPoolWorkloadClassifierPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            sqlPoolName = sqlPoolName ?: throw PulumiNullFieldException("sqlPoolName"),
            workloadClassifierName = workloadClassifierName ?: throw
                PulumiNullFieldException("workloadClassifierName"),
            workloadGroupName = workloadGroupName ?: throw PulumiNullFieldException("workloadGroupName"),
            workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
        )
}
